@@ -32,7 +32,6 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-icon-factory.h"
 #include "nautilus-icon-private.h"
-#include "nautilus-theme.h"
 #include <eel/eel-art-extensions.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
@@ -49,6 +48,7 @@
 #include <libart_lgpl/art_rgb_affine.h>
 #include <libart_lgpl/art_rgb_rgba_affine.h>
 #include <libart_lgpl/art_svp_vpath.h>
+#include <librsvg/rsvg.h>
 #include <libgnome/gnome-i18n.h>
 #include <eel/eel-canvas-util.h>
 #include <atk/atkimage.h>
@@ -707,7 +707,7 @@ compute_text_rectangle (const NautilusIconCanvasItem *item,
 	if (NAUTILUS_ICON_CONTAINER (EEL_CANVAS_ITEM (item)->canvas)->details->label_position == NAUTILUS_ICON_LABEL_POSITION_BESIDE) {
                 text_rectangle.x0 = icon_rectangle.x1;
                 text_rectangle.x1 = text_rectangle.x0 + text_width;
-                text_rectangle.y0 = icon_rectangle.y0;
+                text_rectangle.y0 = (icon_rectangle.y0 + icon_rectangle.y1) / 2- (int) text_height / 2;
                 text_rectangle.y1 = text_rectangle.y0 + text_height + LABEL_OFFSET / pixels_per_unit;
 	} else {
                 text_rectangle.x0 = (icon_rectangle.x0 + icon_rectangle.x1) / 2 - (int) text_width / 2;
@@ -1139,7 +1139,7 @@ draw_stretch_handles (NautilusIconCanvasItem *item, GdkDrawable *drawable,
 
 	gc = gdk_gc_new (drawable);
 
-	knob_filename = nautilus_theme_get_image_path ("knob.png");
+	knob_filename = nautilus_pixmap_file ("knob.png");
 	knob_pixbuf = gdk_pixbuf_new_from_file (knob_filename, NULL);
 	knob_width = gdk_pixbuf_get_width (knob_pixbuf);
 	knob_height = gdk_pixbuf_get_height (knob_pixbuf);
@@ -1345,6 +1345,7 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 	EelCanvas *canvas;
 	char *audio_filename;
 	GdkPixbuf *temp_pixbuf, *old_pixbuf, *audio_pixbuf;
+	double zoom;
 	
 	temp_pixbuf = icon_item->details->pixbuf;
 	canvas = EEL_CANVAS_ITEM(icon_item)->canvas;
@@ -1365,10 +1366,14 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 		/* if the icon is currently being previewed, superimpose an image to indicate that */
 		/* audio is the only kind of previewing right now, so this code isn't as general as it could be */
 		if (icon_item->details->is_active) {
+			zoom = (double) gdk_pixbuf_get_width (temp_pixbuf) / NAUTILUS_ICON_SIZE_STANDARD;
 			/* Load the audio symbol. */
-			audio_filename = nautilus_pixmap_file ("audio.png");
+			audio_filename = nautilus_pixmap_file ("audio.svg");
 			if (audio_filename != NULL) {
-				audio_pixbuf = gdk_pixbuf_new_from_file (audio_filename, NULL);
+				audio_pixbuf = rsvg_pixbuf_from_file_at_zoom_with_max (audio_filename, zoom, zoom,
+																	   NAUTILUS_ICON_MAXIMUM_SIZE,
+																	   NAUTILUS_ICON_MAXIMUM_SIZE,
+																	   NULL);
 			} else {
 				audio_pixbuf = NULL;
 			}
@@ -1382,8 +1387,7 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 					 gdk_pixbuf_get_width (temp_pixbuf),
 					 gdk_pixbuf_get_height(temp_pixbuf),
 					 0, 0,
-					 canvas->pixels_per_unit,
-					 canvas->pixels_per_unit,
+					 1.0, 1.0,
 					 GDK_INTERP_BILINEAR, 0xFF);
 				
 				g_object_unref (audio_pixbuf);
@@ -2042,7 +2046,7 @@ hit_test_stretch_handle (NautilusIconCanvasItem *item,
 		return FALSE;
 	}
 
-	knob_filename = nautilus_theme_get_image_path ("knob.png");
+	knob_filename = nautilus_pixmap_file ("knob.png");
 	knob_pixbuf = gdk_pixbuf_new_from_file (knob_filename, NULL);
 	knob_width = gdk_pixbuf_get_width (knob_pixbuf);
 	knob_height = gdk_pixbuf_get_height (knob_pixbuf);
