@@ -156,6 +156,7 @@ static void
 net_workarea_changed (FMDesktopIconView *icon_view,
 		      GdkWindow         *window)
 {
+	long *nworkareas = NULL;
 	long *workareas = NULL;
 	GdkAtom type_returned;
 	int format_returned;
@@ -167,23 +168,57 @@ net_workarea_changed (FMDesktopIconView *icon_view,
 
 	icon_container = get_icon_container (icon_view);
 
+	/* Find the number of desktops so we know how long the
+	 * workareas array is going to be (each desktop will have four
+	 * elements in the workareas array describing
+	 * x,y,width,height) */
 	gdk_error_trap_push ();
 	if (!gdk_property_get (window,
-			       gdk_atom_intern ("_NET_WORKAREA", FALSE),
+			       gdk_atom_intern ("_NET_NUMBER_OF_DESKTOPS", FALSE),
 			       gdk_x11_xatom_to_atom (XA_CARDINAL),
-			       0, G_MAXLONG, FALSE,
+			       0, 4, FALSE,
 			       &type_returned,
 			       &format_returned,
 			       &length_returned,
-			       (guchar **) &workareas)) {
+			       (guchar **) &nworkareas)) {
+		g_warning("Can not caclulate _NET_NUMBER_OF_DESKTOPS");
+	}
+	if (gdk_error_trap_pop()
+	    || nworkareas == NULL
+	    || type_returned != gdk_x11_xatom_to_atom (XA_CARDINAL)
+	    || format_returned != 32)
+		g_warning("Can not calculate _NET_NUMBER_OF_DESKTOPS");
+	
+	/* Note : gdk_property_get() is broken (API documents admit
+	 * this).  As a length argument, it expects the number of
+	 * _bytes_ of data you require.  Internally, gdk_property_get
+	 * converts that value to a count of 32 bit (4 byte) elements.
+	 * However, the length returned is in bytes, but is calculated
+	 * via the count of returned elements * sizeof(long).  This
+	 * means on a 64 bit system, the number of bytes you have to
+	 * request does not correspond to the number of bytes you get
+	 * back, and is the reason for the workaround below.
+	 */ 
+	gdk_error_trap_push ();
+	if (nworkareas == NULL || (*nworkareas < 1) 
+	    || !gdk_property_get (window,
+				  gdk_atom_intern ("_NET_WORKAREA", FALSE),
+				  gdk_x11_xatom_to_atom (XA_CARDINAL),
+				  0, ((*nworkareas) * 4 * 4), FALSE,
+				  &type_returned,
+				  &format_returned,
+				  &length_returned,
+				  (guchar **) &workareas)) {
+		g_warning("Can not get _NET_WORKAREA");
 		workareas = NULL;
 	}
 
 	if (gdk_error_trap_pop ()
 	    || workareas == NULL
 	    || type_returned != gdk_x11_xatom_to_atom (XA_CARDINAL)
-	    || (length_returned % 4) != 0
+	    || ((*nworkareas) * 4 * sizeof(long)) != length_returned
 	    || format_returned != 32) {
+		g_warning("Can not determine workarea, guessing at layout");
 		nautilus_icon_container_set_margins (icon_container,
 						     0, 0, 0, 0);
 	} else {
@@ -193,6 +228,9 @@ net_workarea_changed (FMDesktopIconView *icon_view,
 			icon_container, screen, workareas, length_returned / sizeof (long));
 	}
 
+	if (nworkareas != NULL)
+		g_free (nworkareas);
+
 	if (workareas != NULL)
 		g_free (workareas);
 }
@@ -551,14 +589,6 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 	fm_desktop_icon_view_update_icon_container_fonts (desktop_icon_view);
 }
 
-static void
-action_new_terminal_callback (GtkAction *action, gpointer data)
-{
-        g_assert (FM_DIRECTORY_VIEW (data));
-
-	eel_gnome_open_terminal_on_screen (NULL, gtk_widget_get_screen (GTK_WIDGET (data)));
-}
-
 static void
 action_new_launcher_callback (GtkAction *action, gpointer data)
 {
@@ -613,7 +643,9 @@ trash_link_is_selection (FMDirectoryView *view)
 	if (eel_g_list_exactly_one_item (selection) &&
 	    NAUTILUS_IS_DESKTOP_ICON_FILE (selection->data)) {
 		link = nautilus_desktop_icon_file_get_link (NAUTILUS_DESKTOP_ICON_FILE (selection->data));
-		if (nautilus_desktop_link_get_link_type (link) == NAUTILUS_DESKTOP_LINK_TRASH) {
+		/* link may be NULL if the link was recently removed (unmounted) */
+		if (link != NULL &&
+		    nautilus_desktop_link_get_link_type (link) == NAUTILUS_DESKTOP_LINK_TRASH) {
 			result = TRUE;
 		}
 		g_object_unref (link);
@@ -645,7 +677,7 @@ real_update_menus (FMDirectoryView *view)
 	gtk_action_set_visible (action, 
 				include_empty_trash);
 	if (include_empty_trash) {
-		label = g_strdup (_("Empty Trash"));
+		label = g_strdup (_("E_mpty Trash"));
 		g_object_set (action , "label", label, NULL);
 		gtk_action_set_sensitive (action,
 					  !nautilus_trash_monitor_is_empty ());
@@ -654,22 +686,27 @@ real_update_menus (FMDirectoryView *view)
 }
 
 static GtkActionEntry desktop_view_entries[] = {
-  { "New Terminal", NULL,                  /* name, stock id */
-    N_("Open T_erminal"), NULL,                /* label, accelerator */
-    N_("Open a new GNOME terminal window"),                   /* tooltip */ 
-    G_CALLBACK (action_new_terminal_callback) },
-  { "New Launcher Desktop", NULL,                  /* name, stock id */
-    N_("Create L_auncher"), NULL,                /* label, accelerator */
-    N_("Create a new launcher"),                   /* tooltip */ 
-    G_CALLBACK (action_new_launcher_callback) },
-  { "Change Background", NULL,                  /* name, stock id */
-    N_("Change Desktop _Background"), NULL,                /* label, accelerator */
-    N_("Show a window that lets you set your desktop background's pattern or color"),                   /* tooltip */ 
-    G_CALLBACK (action_change_background_callback) },
-  { "Empty Trash Conditional", NULL,                  /* name, stock id */
-    N_("Empty Trash"), NULL,                /* label, accelerator */
-    N_("Delete all items in the Trash"),                   /* tooltip */ 
-    G_CALLBACK (action_empty_trash_conditional_callback) },
+	/* name, stock id */
+	{ "New Launcher Desktop", NULL,
+	  /* label, accelerator */
+	  N_("Create L_auncher..."), NULL,
+	  /* tooltip */
+	  N_("Create a new launcher"),
+	  G_CALLBACK (action_new_launcher_callback) },
+	/* name, stock id */
+	{ "Change Background", NULL,
+	  /* label, accelerator */
+	  N_("Change Desktop _Background"), NULL,
+	  /* tooltip */
+	  N_("Show a window that lets you set your desktop background's pattern or color"),
+	  G_CALLBACK (action_change_background_callback) },
+	/* name, stock id */
+	{ "Empty Trash Conditional", NULL,
+	  /* label, accelerator */
+	  N_("Empty Trash"), NULL,
+	  /* tooltip */
+	  N_("Delete all items in the Trash"),
+	  G_CALLBACK (action_empty_trash_conditional_callback) },
 };
 
 static void
@@ -748,7 +785,7 @@ fm_desktop_icon_view_supports_uri (const char *uri,
 			   GnomeVFSFileType file_type,
 			   const char *mime_type)
 {
-	if (g_str_has_prefix (uri, "x-nautilus-desktop:")) {
+	if (g_str_has_prefix (uri, EEL_DESKTOP_URI)) {
 		return TRUE;
 	}
 
@@ -758,7 +795,11 @@ fm_desktop_icon_view_supports_uri (const char *uri,
 static NautilusViewInfo fm_desktop_icon_view = {
 	FM_DESKTOP_ICON_VIEW_ID,
 	N_("Desktop"),
-	N_("_Desktop"),
+	N_("View as Desktop"),
+	N_("View as _Desktop"),
+	N_("The desktop view encountered an error."),
+	N_("The desktop view encountered an error while starting up."),
+	N_("Display this location with the desktop view."),
 	fm_desktop_icon_view_create,
 	fm_desktop_icon_view_supports_uri
 };
@@ -767,7 +808,11 @@ void
 fm_desktop_icon_view_register (void)
 {
 	fm_desktop_icon_view.label = _(fm_desktop_icon_view.label);
-	fm_desktop_icon_view.label_with_mnemonic = _(fm_desktop_icon_view.label_with_mnemonic);
+	fm_desktop_icon_view.view_as_label = _(fm_desktop_icon_view.view_as_label);
+	fm_desktop_icon_view.view_as_label_with_mnemonic = _(fm_desktop_icon_view.view_as_label_with_mnemonic);
+	fm_desktop_icon_view.error_label = _(fm_desktop_icon_view.error_label);
+	fm_desktop_icon_view.startup_error_label = _(fm_desktop_icon_view.startup_error_label);
+	fm_desktop_icon_view.display_location_label = _(fm_desktop_icon_view.display_location_label);
 	
 	nautilus_view_factory_register (&fm_desktop_icon_view);
 }
