@@ -28,7 +28,11 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-vfs-extensions.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-volume.h>
+#include <glib/gi18n.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkvbox.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
@@ -126,7 +130,7 @@ connect_to_server (NautilusConnectServerDialog *dialog)
 
 	if (type == TYPE_URI) {
 		user_uri = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->uri_entry), 0, -1);
-		uri = eel_make_uri_from_input (user_uri);
+		uri = gnome_vfs_make_uri_from_input (user_uri);
 		g_free (user_uri);
 	
 		vfs_uri = gnome_vfs_uri_new (uri);
@@ -144,7 +148,7 @@ connect_to_server (NautilusConnectServerDialog *dialog)
 		}
 	} else {
 		char *method, *user, *port, *initial_path, *server, *folder;
-		char *t;
+		char *t, *join;
 		gboolean free_initial_path, free_user, free_port;
 
 		server = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->server_entry), 0, -1);
@@ -196,23 +200,36 @@ connect_to_server (NautilusConnectServerDialog *dialog)
 		folder = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->folder_entry), 0, -1);
 		if (dialog->details->user_entry->parent != NULL) {
 			free_user = TRUE;
-			user = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->user_entry), 0, -1);
+			
+			t = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->user_entry), 0, -1);
+
+			user = gnome_vfs_escape_string (t);
+
+			g_free (t);
 		}
 
 		if (folder[0] != 0 &&
 		    folder[0] != '/') {
-			t = folder;
-			folder = g_strconcat ("/", t, NULL);
-			g_free (t);
+			join = "/";
+		} else {
+			join = "";
 		}
-		
-		uri = g_strdup_printf ("%s://%s%s%s%s%s%s%s",
+
+		t = folder;
+		folder = g_strconcat (initial_path, join, t, NULL);
+		g_free (t);
+
+		t = folder;
+		folder = gnome_vfs_escape_path_string (t);
+		g_free (t);
+
+		uri = g_strdup_printf ("%s://%s%s%s%s%s%s",
 				       method,
 				       user, (user[0] != 0) ? "@" : "",
 				       server,
 				       (port[0] != 0) ? ":" : "", port,
-				       initial_path,
 				       folder);
+
 		if (free_initial_path) {
 			g_free (initial_path);
 		}
@@ -270,16 +287,16 @@ connect_to_server (NautilusConnectServerDialog *dialog)
 	}
 	
 	gnome_vfs_connect_to_server (uri, name, icon);
-	gtk_widget_destroy (GTK_WIDGET (dialog));
-
+	gtk_widget_hide (GTK_WIDGET (dialog));
 
 	if (!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
-		nautilus_application_present_spatial_window (dialog->details->application,
-							     NULL,
-							     uri,
-							     gtk_widget_get_screen (GTK_WIDGET (dialog)));
+		nautilus_connect_server_dialog_present_uri (dialog->details->application,
+							    uri,
+							    GTK_WIDGET (dialog));
 	}
 
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
 	g_free (uri);
 	g_free (name);
 }
@@ -289,20 +306,11 @@ response_callback (NautilusConnectServerDialog *dialog,
 		   int response_id,
 		   gpointer data)
 {
-	NautilusWindow *window;
-	
 	switch (response_id) {
 	case RESPONSE_BROWSE:
-		if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
-			window = nautilus_application_create_navigation_window (dialog->details->application,
-										gtk_widget_get_screen (GTK_WIDGET (dialog)));
-			nautilus_window_go_to (window, "network:///");
-		} else {
-			nautilus_application_present_spatial_window (dialog->details->application,
-								     NULL,
-								     "network:///",
-								     gtk_widget_get_screen (GTK_WIDGET (dialog)));
-		}
+		nautilus_connect_server_dialog_present_uri (dialog->details->application,
+							    "network:///",
+							    GTK_WIDGET (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	case RESPONSE_CONNECT:
@@ -710,9 +718,8 @@ nautilus_connect_server_dialog_new (NautilusWindow *window)
 	if (window) {
 		gtk_window_set_screen (GTK_WINDOW (dialog),
 				       gtk_window_get_screen (GTK_WINDOW (window)));
+		NAUTILUS_CONNECT_SERVER_DIALOG (dialog)->details->application = window->application;
 	}
 
-	NAUTILUS_CONNECT_SERVER_DIALOG (dialog)->details->application = window->application;
-
 	return dialog;
 }
