@@ -73,7 +73,6 @@
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
 #include <libnautilus-private/nautilus-sidebar.h>
-#include <libnautilus-private/nautilus-theme.h>
 #include <libnautilus-private/nautilus-view-factory.h>
 #include <libnautilus-private/nautilus-clipboard.h>
 #include <libnautilus-private/nautilus-undo.h>
@@ -605,14 +604,11 @@ create_view_as_menu_item (NautilusWindow *window,
 			  guint index)
 {
 	GtkWidget *menu_item;
-        char *menu_label;
 	const NautilusViewInfo *info;
 
 	info = nautilus_view_factory_lookup (identifier);
 
-	menu_label = g_strdup_printf (_("View as %s"), _(info->label));
-	menu_item = gtk_menu_item_new_with_mnemonic (menu_label);
-	g_free (menu_label);
+	menu_item = gtk_menu_item_new_with_mnemonic (_(info->view_as_label));
 
 	g_signal_connect_object (menu_item, "activate",
 				 G_CALLBACK (view_as_menu_switch_views_callback),
@@ -686,7 +682,7 @@ real_set_title (NautilusWindow *window, const char *title)
 	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS,
 			 set_title, (window, title));
 	
-	full_title = g_strdup_printf (_("File Browser: %s"), title);
+	full_title = g_strdup_printf (_("%s - File Browser"), title);
 
 	window_title = eel_str_middle_truncate (full_title, MAX_TITLE_LENGTH);
 	gtk_window_set_title (GTK_WINDOW (window), window_title);
