@@ -58,7 +58,6 @@
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-monitor.h>
-#include <libnautilus-private/nautilus-theme.h>
 #include <libnautilus-private/nautilus-view-factory.h>
 #include <libnautilus-private/nautilus-window-info.h>
 
@@ -123,7 +122,7 @@ set_displayed_location (NautilusWindow *window, const char *location)
                 recreate = TRUE;
         } else {
                 bookmark_uri = nautilus_bookmark_get_uri (window->current_location_bookmark);
-                recreate = !eel_uris_match (bookmark_uri, location);
+                recreate = !gnome_vfs_uris_match (bookmark_uri, location);
                 g_free (bookmark_uri);
         }
         
@@ -146,7 +145,7 @@ check_bookmark_location_matches (NautilusBookmark *bookmark, const char *uri)
 	char *bookmark_uri;
 
 	bookmark_uri = nautilus_bookmark_get_uri (bookmark);
-	if (!eel_uris_match (uri, bookmark_uri)) {
+	if (!gnome_vfs_uris_match (uri, bookmark_uri)) {
 		g_warning ("bookmark uri is %s, but expected %s", bookmark_uri, uri);
 	}
 	g_free (bookmark_uri);
@@ -254,7 +253,7 @@ handle_go_elsewhere (NautilusWindow *window, const char *location)
                          * This also avoids a problem where set_displayed_location
                          * didn't update last_location_bookmark since the uri didn't change.
                          */
-                        if (!eel_uris_match (window->details->location, location)) {
+                        if (!gnome_vfs_uris_match (window->details->location, location)) {
                                 /* Store bookmark for current location in back list, unless there is no current location */
                                 check_last_bookmark_location_matches_window (window);
                                 /* Use the first bookmark in the history list rather than creating a new one. */
@@ -566,40 +565,52 @@ nautilus_window_get_view_label (NautilusWindow *window)
 	return g_strdup (info->label);
 }
 
-static void
-report_content_view_failure_to_user_internal (NautilusWindow *window,
-                                     	      NautilusView *view,
-                                     	      const char *message,
-					      const char *detail)
+char *
+nautilus_window_get_view_error_label (NautilusWindow *window)
 {
-	char *label;
+	const NautilusViewInfo *info;
 
-	label = nautilus_window_get_view_label (window);
-	message = g_strdup_printf (message, label);
-	eel_show_error_dialog (message, detail, _("View Failed"), GTK_WINDOW (window));
-	g_free (label);
+	info = nautilus_view_factory_lookup (nautilus_window_get_content_view_id (window));
+
+	return g_strdup (info->error_label);
+}
+
+char *
+nautilus_window_get_view_startup_error_label (NautilusWindow *window)
+{
+	const NautilusViewInfo *info;
+
+	info = nautilus_view_factory_lookup (nautilus_window_get_content_view_id (window));
+
+	return g_strdup (info->startup_error_label);
 }
 
 static void
 report_current_content_view_failure_to_user (NautilusWindow *window,
                                      	     NautilusView *view)
 {
-	report_content_view_failure_to_user_internal 
-		(window,
-		 view,
-		 _("The %s view encountered an error and can't continue."),
-		 _("You can choose another view or go to a different location."));
+	char *message;
+
+	message = nautilus_window_get_view_startup_error_label (window);
+	eel_show_error_dialog (message,
+			       _("You can choose another view or go to a different location."),
+			       _("View Failed"),
+			       GTK_WINDOW (window));
+	g_free (message);
 }
 
 static void
 report_nascent_content_view_failure_to_user (NautilusWindow *window,
                                      	     NautilusView *view)
 {
-	report_content_view_failure_to_user_internal 
-		(window,
-		 view,
-		 _("The %s view encountered an error while starting up."),
-		 _("The location cannot be displayed with this viewer."));
+	char *message;
+
+	message = nautilus_window_get_view_error_label (window);
+	eel_show_error_dialog (message,
+			       _("The location cannot be displayed with this viewer."),
+			       _("View Failed"),
+			       GTK_WINDOW (window));
+	g_free (message);
 }
 
 
@@ -906,9 +917,9 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 				   in which case going home would cause an infinite loop, so we
 				   better test for that */
 				
-				if (!eel_uris_match (location, "file:///")) {
+				if (!gnome_vfs_uris_match (location, "file:///")) {
 					home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
-					if (!eel_uris_match (home_uri, location)) {	
+					if (!gnome_vfs_uris_match (home_uri, location)) {	
 						nautilus_window_go_home (NAUTILUS_WINDOW (window));
 					} else {
 						/* the last fallback is to go to a known place that can't be deleted! */
